==> aptechka-0.41.6.tgz: package/lib/popover/index.js <==
var F = (n) => {
  throw TypeError(n);
};
var q = (n, a, t) => a.has(n) || F("Cannot " + t);
var e = (n, a, t) => (q(n, a, "read from private field"), t ? t.call(n) : a.get(n)), s = (n, a, t) => a.has(n) ? F("Cannot add the same private member more than once") : a instanceof WeakSet ? a.add(n) : a.set(n, t), i = (n, a, t, h) => (q(n, a, "write to private field"), h ? h.call(n, t) : a.set(n, t), t), m = (n, a, t) => (q(n, a, "access private method"), t);
import { CSSProperty as E } from "../css-property/index.js";
import { S as K } from "../Store-Cm3LPXlx.js";
import { d as z } from "../events-CsVF98U6.js";
import { d as Q } from "../function-C10DGppn.js";
import { g as X } from "../style-j2TwriJ_.js";
import { u as Y, p as Z } from "../url-B5eH5z6S.js";
import { windowResizer as G } from "../window-resizer/vanilla/index.js";
import { i as ee } from "../browser-0zX67oeU.js";
var x, d, V, T, p, v, u, g, f, y, L, w, l, J, A, N, k, B, S, _, O, P, D;
const c = class c extends HTMLElement {
  constructor() {
    super(...arguments);
    s(this, l);
    s(this, x);
    s(this, d);
    s(this, V);
    s(this, T);
    s(this, p);
    s(this, v);
    s(this, u);
    s(this, g);
    s(this, f);
    s(this, y);
    s(this, L);
    s(this, w);
    s(this, A);
    s(this, k);
    s(this, S);
    s(this, _);
    s(this, O);
    s(this, P);
    this.urlValue = "", i(this, x, -1), i(this, d, new K(!1)), i(this, p, new E(this, "--history", !1)), i(this, v, new E(this, "--restore", !1)), i(this, u, new E(this, "--dominance", 0)), i(this, g, new E(this, "--group", "")), i(this, f, new E(this, "--click-outside", !1)), i(this, y, new E(this, "--escape", !1)), i(this, L, !1), this.open = (t) => {
      if (e(this, d).current)
        return;
      i(this, w, t == null ? void 0 : t.trigger), e(this, u).current && (c.__opened = c.__opened.filter((o) => o !== this && m(this, l, D).call(this, this, o) ? (o.close(), !1) : !0)), c.__opened.push(this), i(this, x, c.__opened.length - 1), clearTimeout(e(this, V)), this.classList.remove("closing"), this.classList.add("triggered"), this.style.display = "block", z(this, "popoverTriggered", {
        custom: !0,
        detail: {
          trigger: e(this, w)
        }
      }), e(this, p).current && e(this, L) && history.pushState(history.state, "", e(this, l, J)), e(this, d).current = !0;
      const h = () => {
        addEventListener("click", e(this, A)), addEventListener("keydown", e(this, k)), e(this, P).call(this), this.style.opacity = "1", this.classList.add("opened"), z(this, "popoverOpened", {
          custom: !0,
          detail: {
            trigger: e(this, w)
          }
        }), i(this, T, void 0), this.setAttribute("aria-hidden", "false");
      };
      t != null && t.skipTransition ? h() : i(this, T, setTimeout(h, 10));
    }, this.close = () => {
      e(this, d).current && (removeEventListener("click", e(this, A)), removeEventListener("keydown", e(this, k)), e(this, d).current = !1, c.__opened = c.__opened.filter((t) => t === this ? !1 : !e(t, T) && m(this, l, D).call(this, this, t) ? (t.close(), !1) : !0), m(this, l, N).call(this), this.classList.remove("opened"), this.classList.add("closing"), this.setAttribute("aria-hidden", "true"), this.style.opacity = "0", z(this, "popoverClosing", {
        custom: !0
      }), setTimeout(() => {
        this.classList.remove("triggered"), this.classList.remove("closing"), this.style.display = "none", z(this, "popoverClosed", {
          custom: !0
        });
      }, X(this) + 10));
    }, i(this, A, (t) => {
      e(this, f).current && m(this, l, B).call(this, () => {
        var U;
        const h = t.composedPath();
        if (h.find(
          (j) => j instanceof HTMLElement && j.hasAttribute("data-popover-content")
        ))
          return;
        const o = h[0], I = o instanceof Node && (this.contains(o) || ((U = this.shadowRoot) == null ? void 0 : U.contains(o))), C = o instanceof HTMLElement && o.hasAttribute("data-outside");
        (!I || C) && this.close();
      });
    }), i(this, k, (t) => {
      e(this, y).current && m(this, l, B).call(this, () => {
        t.code === "Escape" && this.close();
      });
    }), i(this, S, () => {
      i(this, L, !1), e(this, d).current && e(this, p).current && !location.search.includes(this.id) ? this.close() : !e(this, d).current && e(this, p).current && location.search.includes(this.id) && this.open({ trigger: this.idWithValue }), i(this, L, !0);
    }), i(this, _, () => {
      this.style.setProperty("--content-width", "initial"), this.style.setProperty("--content-height", "initial"), e(this, O).call(this);
    }), i(this, O, Q(() => {
      e(this, P).call(this);
    }, 10)), i(this, P, () => {
      this.style.setProperty("--content-width", this.scrollWidth + "px"), this.style.setProperty("--content-height", this.scrollHeight + "px");
    });
  }
  get history() {
    return e(this, p);
  }
  get restore() {
    return e(this, v);
  }
  get dominance() {
    return e(this, u);
  }
  get group() {
    return e(this, g);
  }
  get clickOutside() {
    return e(this, f);
  }
  get escape() {
    return e(this, y);
  }
  get opened() {
    return e(this, d);
  }
  get lastTrigger() {
    return e(this, w);
  }
  get idWithValue() {
    return `${this.id}${this.urlValue ? "=" + this.urlValue : ""}`;
  }
  updateUrlValue(t) {
    this.urlValue = (t == null ? void 0 : t.toString()) || "", e(this, d).current && Y(this.id, t);
  }
  connectedCallback() {
    e(this, p).observe(), e(this, v).observe(), e(this, u).observe(), e(this, g).observe(), e(this, f).observe(), e(this, y).observe(), this.style.opacity = "0", this.style.display = "none", this.setAttribute("role", "dialog"), this.setAttribute("aria-hidden", "true"), this.classList.remove("closing"), this.classList.remove("closed"), this.classList.remove("triggered"), this.classList.remove("opened"), addEventListener("popstate", e(this, S)), setTimeout(() => {
      e(this, v).current ? (this.urlValue = Z(location.search)[this.id], e(this, S).call(this)) : (m(this, l, N).call(this), i(this, L, !0));
    }, 0), G.subscribe(e(this, _));
  }
  disconnectedCallback() {
    G.unsubscribe(e(this, _)), e(this, p).close(), e(this, v).close(), e(this, u).close(), e(this, g).close(), e(this, f).close(), e(this, y).close(), this.style.opacity = "", this.style.display = "", this.removeAttribute("role"), this.removeAttribute("aria-hidden"), c.__opened = c.__opened.filter((t) => t !== this), clearTimeout(e(this, V)), clearTimeout(e(this, T)), removeEventListener("popstate", e(this, S)), removeEventListener("click", e(this, A)), removeEventListener("keydown", e(this, k)), this.style.removeProperty("--content-width"), this.style.removeProperty("--content-height"), m(this, l, N).call(this);
  }
};
x = new WeakMap(), d = new WeakMap(), V = new WeakMap(), T = new WeakMap(), p = new WeakMap(), v = new WeakMap(), u = new WeakMap(), g = new WeakMap(), f = new WeakMap(), y = new WeakMap(), L = new WeakMap(), w = new WeakMap(), l = new WeakSet(), J = function() {
  return `${location.pathname}${location.search ? location.search + "&" : "?"}${this.idWithValue}`;
}, A = new WeakMap(), N = function() {
  if (e(this, p).current) {
    const t = new URL(location.href);
    t.searchParams.delete(this.id), history.replaceState(history.state, "", t.href);
  }
}, k = new WeakMap(), B = function(t) {
  (c.__opened[e(this, x) - 1] || c.__opened.length === 1 || c.__opened.filter((h) => h !== this).every((h) => e(this, u).current > h.dominance.current)) && t();
}, S = new WeakMap(), _ = new WeakMap(), O = new WeakMap(), P = new WeakMap(), D = function(t, h) {
  if (e(t, g).current === e(h, g).current && t.dominance.current >= h.dominance.current)
    return !0;
}, c.__opened = [];
let W = c;
customElements.get("e-popover") || customElements.define("e-popover", W);
var r, b, $, H, M, R;
class te extends HTMLElement {
  constructor() {
    super();
    s(this, r);
    s(this, b, new E(this, "--type", "open"));
    s(this, $, () => {
      this.classList.add("triggered");
    });
    s(this, H, () => {
      this.classList.add("opened"), this.setAttribute("aria-expanded", "true");
    });
    s(this, M, () => {
      this.classList.remove("opened");
    });
    s(this, R, () => {
      this.classList.remove("triggered"), this.setAttribute("aria-expanded", "false");
    });
    ee && (this.addEventListener("click", () => {
      if (e(this, r)) {
        const t = e(this, b).current;
        t === "open" || t === "toggle" && !e(this, r).opened.current ? e(this, r).open({ trigger: this }) : (t === "close" || t === "toggle" && e(this, r).opened.current) && e(this, r).close();
      }
    }), this.addEventListener("keydown", (t) => {
      t.code === "Space" && t.currentTarget.click();
    }));
  }
  get type() {
    return e(this, b);
  }
  get popoverElement() {
    return e(this, r);
  }
  connectedCallback() {
    var h;
    e(this, b).subscribe((o) => {
      e(this, r) instanceof W && (o.current !== "close" ? (this.setAttribute("aria-haspopup", "true"), this.setAttribute(
        "aria-expanded",
        e(this, r).opened.current ? "true" : "false"
      ), this.setAttribute("aria-controls", e(this, r).id || "")) : (this.removeAttribute("aria-haspopup"), this.removeAttribute("aria-expanded"), this.removeAttribute("aria-controls")));
    }), this.hasAttribute("tabindex") || (this.tabIndex = 0);
    const t = this.getAttribute("target");
    if (t) {
      let o = null;
      if (t === "parent") {
        const I = this.closest("[popover-target]");
        if (I)
          o = I;
        else {
          const C = this.getRootNode();
          C instanceof ShadowRoot ? o = C.host.closest("[popover-target]") : C instanceof HTMLElement && (o = C.closest("[popover-target]"));
        }
      } else t === "sibling" ? o = (h = this.parentElement) == null ? void 0 : h.querySelector("[popover-target]") : o = document.querySelector(`#${t}`) || this.getRootNode().querySelector(`#${t}`);
      o instanceof HTMLElement ? (i(this, r, o), e(this, r).addEventListener(
        "popoverTriggered",
        e(this, $)
      ), e(this, r).addEventListener(
        "popoverOpened",
        e(this, H)
      ), e(this, r).addEventListener(
        "popoverClosing",
        e(this, M)
      ), e(this, r).addEventListener(
        "popoverClosed",
        e(this, R)
      )) : console.warn(this, `target ${t} not found`);
    }
    this.isConnected && e(this, b).observe();
  }
  disconnectedCallback() {
    e(this, b).unobserve(), this.removeAttribute("aria-haspopup"), this.removeAttribute("aria-expanded"), this.removeAttribute("aria-controls"), e(this, r) && (e(this, r).removeEventListener(
      "popoverTriggered",
      e(this, $)
    ), e(this, r).removeEventListener(
      "popoverOpened",
      e(this, H)
    ), e(this, r).removeEventListener(
      "popoverClosing",
      e(this, M)
    ), e(this, r).removeEventListener(
      "popoverClosed",
      e(this, R)
    ));
  }
}
r = new WeakMap(), b = new WeakMap(), $ = new WeakMap(), H = new WeakMap(), M = new WeakMap(), R = new WeakMap();
customElements.get("e-popover-button") || customElements.define("e-popover-button", te);
export {
  te as PopoverButtonElement,
  W as PopoverElement
};

==> aptechka-0.42.5.tgz: package/lib/popover/index.js <==
var F = (n) => {
  throw TypeError(n);
};
var q = (n, a, t) => a.has(n) || F("Cannot " + t);
var e = (n, a, t) => (q(n, a, "read from private field"), t ? t.call(n) : a.get(n)), s = (n, a, t) => a.has(n) ? F("Cannot add the same private member more than once") : a instanceof WeakSet ? a.add(n) : a.set(n, t), i = (n, a, t, h) => (q(n, a, "write to private field"), h ? h.call(n, t) : a.set(n, t), t), m = (n, a, t) => (q(n, a, "access private method"), t);
import { CSSProperty as E } from "../css-property/index.js";
import { S as K } from "../Store-Cm3LPXlx.js";
import { d as z } from "../events-CsVF98U6.js";
import { d as Q } from "../function-C10DGppn.js";
import { g as X } from "../style-j2TwriJ_.js";
import { u as Y, p as Z } from "../url-B5eH5z6S.js";
import { windowResizer as G } from "../window-resizer/index.js";
import { i as ee } from "../browser-0zX67oeU.js";
var x, d, V, T, p, v, u, g, f, y, L, w, l, J, A, N, k, B, S, _, O, P, D;
const c = class c extends HTMLElement {
  constructor() {
    super(...arguments);
    s(this, l);
    s(this, x);
    s(this, d);
    s(this, V);
    s(this, T);
    s(this, p);
    s(this, v);
    s(this, u);
    s(this, g);
    s(this, f);
    s(this, y);
    s(this, L);
    s(this, w);
    s(this, A);
    s(this, k);
    s(this, S);
    s(this, _);
    s(this, O);
    s(this, P);
    this.urlValue = "", i(this, x, -1), i(this, d, new K(!1)), i(this, p, new E(this, "--history", !1)), i(this, v, new E(this, "--restore", !1)), i(this, u, new E(this, "--dominance", 0)), i(this, g, new E(this, "--group", "")), i(this, f, new E(this, "--click-outside", !1)), i(this, y, new E(this, "--escape", !1)), i(this, L, !1), this.open = (t) => {
      if (e(this, d).current)
        return;
      i(this, w, t == null ? void 0 : t.trigger), e(this, u).current && (c.__opened = c.__opened.filter((o) => o !== this && m(this, l, D).call(this, this, o) ? (o.close(), !1) : !0)), c.__opened.push(this), i(this, x, c.__opened.length - 1), clearTimeout(e(this, V)), this.classList.remove("closing"), this.classList.add("triggered"), this.style.display = "block", z(this, "popoverTriggered", {
        custom: !0,
        detail: {
          trigger: e(this, w)
        }
      }), e(this, p).current && e(this, L) && history.pushState(history.state, "", e(this, l, J)), e(this, d).current = !0;
      const h = () => {
        addEventListener("click", e(this, A)), addEventListener("keydown", e(this, k)), e(this, P).call(this), this.style.opacity = "1", this.classList.add("opened"), z(this, "popoverOpened", {
          custom: !0,
          detail: {
            trigger: e(this, w)
          }
        }), i(this, T, void 0), this.setAttribute("aria-hidden", "false");
      };
      t != null && t.skipTransition ? h() : i(this, T, setTimeout(h, 10));
    }, this.close = () => {
      e(this, d).current && (removeEventListener("click", e(this, A)), removeEventListener("keydown", e(this, k)), e(this, d).current = !1, c.__opened = c.__opened.filter((t) => t === this ? !1 : !e(t, T) && m(this, l, D).call(this, this, t) ? (t.close(), !1) : !0), m(this, l, N).call(this), this.classList.remove("opened"), this.classList.add("closing"), this.setAttribute("aria-hidden", "true"), this.style.opacity = "0", z(this, "popoverClosing", {
        custom: !0
      }), setTimeout(() => {
        this.classList.remove("triggered"), this.classList.remove("closing"), this.style.display = "none", z(this, "popoverClosed", {
          custom: !0
        });
      }, X(this) + 10));
    }, i(this, A, (t) => {
      e(this, f).current && m(this, l, B).call(this, () => {
        var U;
        const h = t.composedPath();
        if (h.find(
          (j) => j instanceof HTMLElement && j.hasAttribute("data-popover-content")
        ))
          return;
        const o = h[0], I = o instanceof Node && (this.contains(o) || ((U = this.shadowRoot) == null ? void 0 : U.contains(o))), C = o instanceof HTMLElement && o.hasAttribute("data-outside");
        (!I || C) && this.close();
      });
    }), i(this, k, (t) => {
      e(this, y).current && m(this, l, B).call(this, () => {
        t.code === "Escape" && this.close();
      });
    }), i(this, S, () => {
      i(this, L, !1), e(this, d).current && e(this, p).current && !location.search.includes(this.id) ? this.close() : !e(this, d).current && e(this, p).current && location.search.includes(this.id) && this.open({ trigger: this.idWithValue }), i(this, L, !0);
    }), i(this, _, () => {
      this.style.setProperty("--content-width", "initial"), this.style.setProperty("--content-height", "initial"), e(this, O).call(this);
    }), i(this, O, Q(() => {
      e(this, P).call(this);
    }, 10)), i(this, P, () => {
      this.style.setProperty("--content-width", this.scrollWidth + "px"), this.style.setProperty("--content-height", this.scrollHeight + "px");
    });
  }
  get history() {
    return e(this, p);
  }
  get restore() {
    return e(this, v);
  }
  get dominance() {
    return e(this, u);
  }
  get group() {
    return e(this, g);
  }
  get clickOutside() {
    return e(this, f);
  }
  get escape() {
    return e(this, y);
  }
  get opened() {
    return e(this, d);
  }
  get lastTrigger() {
    return e(this, w);
  }
  get idWithValue() {
    return `${this.id}${this.urlValue ? "=" + this.urlValue : ""}`;
  }
  updateUrlValue(t) {
    this.urlValue = (t == null ? void 0 : t.toString()) || "", e(this, d).current && Y(this.id, t);
  }
  connectedCallback() {
    e(this, p).observe(), e(this, v).observe(), e(this, u).observe(), e(this, g).observe(), e(this, f).observe(), e(this, y).observe(), this.style.opacity = "0", this.style.display = "none", this.setAttribute("role", "dialog"), this.setAttribute("aria-hidden", "true"), this.classList.remove("closing"), this.classList.remove("closed"), this.classList.remove("triggered"), this.classList.remove("opened"), addEventListener("popstate", e(this, S)), setTimeout(() => {
      e(this, v).current ? (this.urlValue = Z(location.search)[this.id], e(this, S).call(this)) : (m(this, l, N).call(this), i(this, L, !0));
    }, 0), G.subscribe(e(this, _));
  }
  disconnectedCallback() {
    G.unsubscribe(e(this, _)), e(this, p).close(), e(this, v).close(), e(this, u).close(), e(this, g).close(), e(this, f).close(), e(this, y).close(), this.style.opacity = "", this.style.display = "", this.removeAttribute("role"), this.removeAttribute("aria-hidden"), c.__opened = c.__opened.filter((t) => t !== this), clearTimeout(e(this, V)), clearTimeout(e(this, T)), removeEventListener("popstate", e(this, S)), removeEventListener("click", e(this, A)), removeEventListener("keydown", e(this, k)), this.style.removeProperty("--content-width"), this.style.removeProperty("--content-height"), m(this, l, N).call(this);
  }
};
x = new WeakMap(), d = new WeakMap(), V = new WeakMap(), T = new WeakMap(), p = new WeakMap(), v = new WeakMap(), u = new WeakMap(), g = new WeakMap(), f = new WeakMap(), y = new WeakMap(), L = new WeakMap(), w = new WeakMap(), l = new WeakSet(), J = function() {
  return `${location.pathname}${location.search ? location.search + "&" : "?"}${this.idWithValue}`;
}, A = new WeakMap(), N = function() {
  if (e(this, p).current) {
    const t = new URL(location.href);
    t.searchParams.delete(this.id), history.replaceState(history.state, "", t.href);
  }
}, k = new WeakMap(), B = function(t) {
  (c.__opened[e(this, x) - 1] || c.__opened.length === 1 || c.__opened.filter((h) => h !== this).every((h) => e(this, u).current > h.dominance.current)) && t();
}, S = new WeakMap(), _ = new WeakMap(), O = new WeakMap(), P = new WeakMap(), D = function(t, h) {
  if (e(t, g).current === e(h, g).current && t.dominance.current >= h.dominance.current)
    return !0;
}, c.__opened = [];
let W = c;
customElements.get("e-popover") || customElements.define("e-popover", W);
var r, b, $, H, M, R;
class te extends HTMLElement {
  constructor() {
    super();
    s(this, r);
    s(this, b, new E(this, "--type", "open"));
    s(this, $, () => {
      this.classList.add("triggered");
    });
    s(this, H, () => {
      this.classList.add("opened"), this.setAttribute("aria-expanded", "true");
    });
    s(this, M, () => {
      this.classList.remove("opened");
    });
    s(this, R, () => {
      this.classList.remove("triggered"), this.setAttribute("aria-expanded", "false");
    });
    ee && (this.addEventListener("click", () => {
      if (e(this, r)) {
        const t = e(this, b).current;
        t === "open" || t === "toggle" && !e(this, r).opened.current ? e(this, r).open({ trigger: this }) : (t === "close" || t === "toggle" && e(this, r).opened.current) && e(this, r).close();
      }
    }), this.addEventListener("keydown", (t) => {
      t.code === "Space" && t.currentTarget.click();
    }));
  }
  get type() {
    return e(this, b);
  }
  get popoverElement() {
    return e(this, r);
  }
  connectedCallback() {
    var h;
    e(this, b).subscribe((o) => {
      e(this, r) instanceof W && (o.current !== "close" ? (this.setAttribute("aria-haspopup", "true"), this.setAttribute(
        "aria-expanded",
        e(this, r).opened.current ? "true" : "false"
      ), this.setAttribute("aria-controls", e(this, r).id || "")) : (this.removeAttribute("aria-haspopup"), this.removeAttribute("aria-expanded"), this.removeAttribute("aria-controls")));
    }), this.hasAttribute("tabindex") || (this.tabIndex = 0);
    const t = this.getAttribute("target");
    if (t) {
      let o = null;
      if (t === "parent") {
        const I = this.closest("[popover-target]");
        if (I)
          o = I;
        else {
          const C = this.getRootNode();
          C instanceof ShadowRoot ? o = C.host.closest("[popover-target]") : C instanceof HTMLElement && (o = C.closest("[popover-target]"));
        }
      } else t === "sibling" ? o = (h = this.parentElement) == null ? void 0 : h.querySelector("[popover-target]") : o = document.querySelector(`#${t}`) || this.getRootNode().querySelector(`#${t}`);
      o instanceof HTMLElement ? (i(this, r, o), e(this, r).addEventListener(
        "popoverTriggered",
        e(this, $)
      ), e(this, r).addEventListener(
        "popoverOpened",
        e(this, H)
      ), e(this, r).addEventListener(
        "popoverClosing",
        e(this, M)
      ), e(this, r).addEventListener(
        "popoverClosed",
        e(this, R)
      )) : console.warn(this, `target ${t} not found`);
    }
    this.isConnected && e(this, b).observe();
  }
  disconnectedCallback() {
    e(this, b).unobserve(), this.removeAttribute("aria-haspopup"), this.removeAttribute("aria-expanded"), this.removeAttribute("aria-controls"), e(this, r) && (e(this, r).removeEventListener(
      "popoverTriggered",
      e(this, $)
    ), e(this, r).removeEventListener(
      "popoverOpened",
      e(this, H)
    ), e(this, r).removeEventListener(
      "popoverClosing",
      e(this, M)
    ), e(this, r).removeEventListener(
      "popoverClosed",
      e(this, R)
    ));
  }
}
r = new WeakMap(), b = new WeakMap(), $ = new WeakMap(), H = new WeakMap(), M = new WeakMap(), R = new WeakMap();
customElements.get("e-popover-button") || customElements.define("e-popover-button", te);
export {
  te as PopoverButtonElement,
  W as PopoverElement
};
